@@ -1,4 +1,5 @@
 from django.contrib import admin
+
 from .models import Zone, NameServer, Record
 
 
@@ -14,4 +15,4 @@ class NameServerAdmin(admin.ModelAdmin):
 
 @admin.register(Record)
 class RecordAdmin(admin.ModelAdmin):
-    list_display = ("zone", "type", "name", "value", "ttl")
+    list_display = ("zone", "type", "name", "value", "ttl", "managed")
