@@ -4,6 +4,7 @@ from netbox_dns.forms import (
     NameServerCSVForm,
     NameServerFilterForm,
     NameServerForm,
+    NameServerBulkEditForm,
     RecordCSVForm,
     RecordFilterForm,
     RecordForm,
@@ -45,12 +46,21 @@ class ZoneView(generic.ObjectView):
 
     queryset = Zone.objects.all()
 
+    def get_extra_context(self, request, instance):
+        ns_warnings, ns_errors = instance.check_nameservers()
+
+        return {
+            "nameserver_warnings": ns_warnings,
+            "nameserver_errors": ns_errors,
+        }
+
 
 class ZoneEditView(generic.ObjectEditView):
     """View for editing and creating a Zone instance."""
 
     queryset = Zone.objects.all()
     model_form = ZoneForm
+    template_name = "netbox_dns/zone_edit.html"
 
 
 class ZoneDeleteView(generic.ObjectDeleteView):
@@ -181,6 +191,13 @@ class NameServerBulkImportView(generic.BulkImportView):
     table = NameServerTable
 
 
+class NameServerBulkEditView(generic.BulkEditView):
+    queryset = NameServer.objects.all()
+    filterset = NameServerFilter
+    table = NameServerTable
+    form = NameServerBulkEditForm
+
+
 class NameServerBulkDeleteView(generic.BulkDeleteView):
     queryset = NameServer.objects.all()
     table = NameServerTable
